@@ -31,9 +31,9 @@
 #'
 #' read_tier_data(sample_data_tier)
 
-read_tier_data <- function(raw_lines,col_types=NULL,col_names=NULL,na_strings=NULL,
-                           left_justified='EXCODE',guess_max=1000,join_tiers=TRUE,
-                           store_v_fmt=TRUE, read_only = NULL){
+read_tier_data <- function(raw_lines, col_types=NULL, col_names=NULL, na_strings=NULL,
+                           left_justified='EXCODE', guess_max=1000, join_tiers=TRUE,
+                           store_v_fmt=TRUE, read_only = NULL, tier_fmt = NULL){
 
   raw_lines <- sanitize_raw_lines(raw_lines)
 
@@ -50,20 +50,30 @@ read_tier_data <- function(raw_lines,col_types=NULL,col_names=NULL,na_strings=NU
     }
   }
 
-#  if(!'DATE'%in%{col_types$cols %>% str_replace_all(c(' '=''))})
-  col_types <- cols(` DATE`=col_character()) %>%
-    {.$cols <- c(.$cols,col_types$cols)
-   .}
+  if(is.null(tier_fmt)){
 
-  # Process header into fixed-width format positions
-  fwf_pos <- map(headline,
-                 ~header_to_fwf_position(.,left_justified,col_types,col_names,read_only))
+    col_types <- cols(` DATE`=col_character()) %>%
+      {.$cols <- c(.$cols,col_types$cols)
+      .}
+
+    # Process header into fixed-width format positions
+    fwf_pos <- map(headline,
+                   ~header_to_fwf_position(.,left_justified, col_types, col_names, read_only))
+
+  }else{
+    # Add code here to convert tier_fmt into fwf_pos
+    fwf_pos <- map(headline,
+                   ~v_fmt_to_fwf_pos(tier_fmt, header = .))
+
+    col_types <- map(fwf_pos,
+                     ~v_fmt_to_col_types(tier_fmt[.$col_names]))
+  }
 
   # Calculate end of each section based on beginning of next section
   end <- c(skip[-1]-1,length(raw_lines))
 
   # Put check_col_types here
-  if(!is.null(col_types)){
+  if(is.null(tier_fmt) & !is.null(col_types)){
     col_types <- map(1:length(skip),~check_col_types(col_types,fwf_pos[[.]]$col_names))
   }
 
@@ -91,7 +101,7 @@ read_tier_data <- function(raw_lines,col_types=NULL,col_names=NULL,na_strings=NU
                               na = na_strings,
                             skip_empty_rows = TRUE,
                             guess_max = guess_max,
-                            col_types=col_types[[i]])
+                            col_types = col_types[[i]])
         }
         return(tdata)
       }) %>%
@@ -115,14 +125,15 @@ read_tier_data <- function(raw_lines,col_types=NULL,col_names=NULL,na_strings=NU
       }
       # Convert DATE column if DATE is not already POSIXct
       potential_date_cols <- colnames(one_df) %>%
-        str_subset('(DATE)|(AT$)|(PFRST)|(PLAST)|(HFRST)|(HLAST)')
+        str_subset('(DATE)|((?<!XL)AT$)|(PFRST)|(PLAST)|(HFRST)|(HLAST)')
       date_cols <- col_types %>%
         {map(.,~names(.$cols)) %>%
             unlist()} %>%
         str_replace_all(c('^ +'='',
                           ' +$'='')) %>%
         { potential_date_cols[(! potential_date_cols %in% .) |
-                               potential_date_cols == 'DATE' ]}
+                               potential_date_cols == 'DATE' |
+                                !is.null(tier_fmt)]}
       one_df <- one_df %>%
         mutate_at(.,date_cols,~convert_to_date(.))
       return(one_df)
